==> 2025-09-20-21-52-27-M9A-M9A-win-x86_64-v3.11.15.zip: README.md <==
<!-- markdownlint-disable MD033 MD041 -->
<div align="center">

<img alt="LOGO" src="https://github.com/user-attachments/assets/b8e4d737-d549-43f3-a2e7-a3727bf615a9" width="256" height="256" />

# M9A

基于全新架构的 亿韭韭韭 小助手。图像技术 + 模拟控制，解放双手！  
由 [MaaFramework](https://github.com/MaaXYZ/MaaFramework) 强力驱动！  
<a href="https://github.com/MAA1999/M9A" target="_blank" style="font-weight: bold;">🔗 本项目 GitHub 仓库</a>

</div>

<p align="center">
  <img alt="Python" src="https://img.shields.io/badge/Python-3776AB?logo=python&logoColor=white">
  <img alt="platform" src="https://img.shields.io/badge/platform-Windows%20%7C%20Linux%20%7C%20macOS-blueviolet">
  <img alt="license" src="https://img.shields.io/github/license/MAA1999/M9A">
  <br>
  <img alt="commit" src="https://img.shields.io/github/commit-activity/m/MAA1999/M9A">
  <img alt="stars" src="https://img.shields.io/github/stars/MAA1999/M9A?style=social">
  <img alt="downloads" src="https://img.shields.io/github/downloads/MAA1999/M9A/total?style=social">
  <a href="https://mirrorchyan.com/zh/projects?rid=M9A&source=m9agh-badge" target="_blank"><img alt="mirrorc" src="https://img.shields.io/badge/Mirror%E9%85%B1-%239af3f6?logo=countingworkspro&logoColor=4f46e5"></a>
</p>

<div align="center">

[English](./README_en.md) | [简体中文](./README.md)

</div>

## 功能列表

- 启动/关闭游戏
- 切换账号
- 收取荒原、魔精收取生产物品
- 每日心相（意志解析）
- 刷体力、最优材料关卡、活动关卡、吃糖选项
- 自动深眠域
- 自动醒梦域
- 银行购物
- 领取日常奖励
- 当期轶事
- 雨中悬想：迷思海（"寻思"周扫荡）
- 局外演绎：山麓的回音（肉鸽）
- 匣中交流赛
- 警铃鸣响时
- 自动推图（测试中）
- 翻斗棋（1600分以下）

## 使用说明

- [新手上路](./docs/zh_cn/manual/新手上路.md)(**使用前必看**)
- [功能介绍](./docs/zh_cn/manual/功能介绍.md)
- [MaaPiCli使用说明](./docs/zh_cn/manual/MaaPiCli.md)
- [连接设置](./docs/zh_cn/manual/连接设置.md)
- [常见问题](./docs/zh_cn/manual/常见问题.md)
- [Mirror酱使用说明](./docs/zh_cn/manual/Mirror酱.md)

## 开发相关

- [开发前须知](./docs/zh_cn/develop/开发前须知.md)
- [项目结构](./docs/zh_cn/develop/项目结构.md)
- [interface.json编写](./docs/zh_cn/develop/interface.json编写.md)
- [Pipeline编写](./docs/zh_cn/develop/Pipeline编写.md)
- [Custom编写](./docs/zh_cn/develop/Custom编写.md)
- [Bug排查](./docs/zh_cn/develop/Bug排查.md)
- [项目重构](./docs/zh_cn/develop/项目重构.md)
- [外服适配](./docs/zh_cn/develop/外服适配.md)
- [文档编写](./docs/zh_cn/develop/文档编写.md)

更多文档请前往 [MaaFramework](https://github.com/MaaXYZ/MaaFramework) 主仓库查看

## Star History

<a href="https://www.star-history.com/#MAA1999/M9A&Date">
 <picture>
   <source media="(prefers-color-scheme: dark)" srcset="https://api.star-history.com/svg?repos=MAA1999/M9A&type=Date&theme=dark" />
   <source media="(prefers-color-scheme: light)" srcset="https://api.star-history.com/svg?repos=MAA1999/M9A&type=Date" />
   <img alt="Star History Chart" src="https://api.star-history.com/svg?repos=MAA1999/M9A&type=Date" />
 </picture>
</a>

## 鸣谢

本项目由 **[MaaFramework](https://github.com/MaaXYZ/MaaFramework)** 强力驱动！  
UI 由 [MFAAvalonia](https://github.com/SweetSmellFox/MFAAvalonia)、~~[MFW-CFA](https://github.com/overflow65537/MFW-PyQt6)~~、~~[MFAWPF](https://github.com/SweetSmellFox/MFAWPF)~~ 大力支持！

感谢以下开发者对本项目作出的贡献:

[![Contributors](https://contrib.rocks/image?repo=MAA1999/M9A&max=1000)](https://github.com/MAA1999/M9A/graphs/contributors)

## Join us

- M9A 交流群 QQ 群：175638678
- M9A 开发群 QQ 群：649344857
- MaaFramework 开发交流 QQ 群: 595990173

==> 2025-10-18-21-54-32-M9A-M9A-win-x86_64-v3.14.2.zip: README.md <==
<!-- markdownlint-disable MD033 MD041 -->
<div align="center">

<img alt="LOGO" src="https://github.com/user-attachments/assets/b8e4d737-d549-43f3-a2e7-a3727bf615a9" width="256" height="256" />

# M9A

基于全新架构的 亿韭韭韭 小助手。图像技术 + 模拟控制，解放双手！  
由 [MaaFramework](https://github.com/MaaXYZ/MaaFramework) 强力驱动！  
<a href="https://github.com/MAA1999/M9A" target="_blank" style="font-weight: bold;">🔗 本项目 GitHub 仓库</a><br>
🌟喜欢本项目就在仓库右上角点个星星吧🌟

</div>

<p align="center">
  <img alt="Python" src="https://img.shields.io/badge/Python-3776AB?logo=python&logoColor=white">
  <img alt="platform" src="https://img.shields.io/badge/platform-Windows%20%7C%20Linux%20%7C%20macOS-blueviolet">
  <img alt="license" src="https://img.shields.io/github/license/MAA1999/M9A">
  <br>
  <img alt="commit" src="https://img.shields.io/github/commit-activity/m/MAA1999/M9A">
  <img alt="stars" src="https://img.shields.io/github/stars/MAA1999/M9A?style=social">
  <img alt="downloads" src="https://img.shields.io/github/downloads/MAA1999/M9A/total?style=social">
  <a href="https://mirrorchyan.com/zh/projects?rid=M9A&source=m9agh-badge" target="_blank"><img alt="mirrorc" src="https://img.shields.io/badge/Mirror%E9%85%B1-%239af3f6?logo=countingworkspro&logoColor=4f46e5"></a>
</p>

<div align="center">

[English](./README_en.md) | [简体中文](./README.md)

</div>

## 功能列表

- 启动/关闭游戏
- 切换账号
- 收取荒原、魔精生产、交付订单、好梦井
- 每日心相（意志解析）
- 刷体力、最优材料关卡、活动关卡
- 自动深眠域
- 自动醒梦域
- 银行购物
- 领取日常奖励
- 当期轶事
- 雨中悬想：迷思海（"寻思"周扫荡）
- 局外演绎：山麓的回音（肉鸽）
- 匣中交流赛
- 警铃鸣响时
- 自动推图（测试中）
- 翻斗棋（1600分以下）
- 雨前漫游指南

## 使用说明

- [新手上路](./docs/zh_cn/manual/新手上路.md)(**使用前必看**)
- [功能介绍](./docs/zh_cn/manual/功能介绍.md)
- [MaaPiCli使用说明](./docs/zh_cn/manual/MaaPiCli.md)
- [连接设置](./docs/zh_cn/manual/连接设置.md)
- [常见问题](./docs/zh_cn/manual/常见问题.md)
- [Mirror酱使用说明](./docs/zh_cn/manual/Mirror酱.md)

## 开发相关

- [开发前须知](./docs/zh_cn/develop/开发前须知.md)
- [项目结构](./docs/zh_cn/develop/项目结构.md)
- [interface.json编写](./docs/zh_cn/develop/interface.json编写.md)
- [Pipeline编写](./docs/zh_cn/develop/Pipeline编写.md)
- [Custom编写](./docs/zh_cn/develop/Custom编写.md)
- [Bug排查](./docs/zh_cn/develop/Bug排查.md)
- [项目重构](./docs/zh_cn/develop/项目重构.md)
- [外服适配](./docs/zh_cn/develop/外服适配.md)
- [文档编写](./docs/zh_cn/develop/文档编写.md)

更多文档请前往 [MaaFramework](https://github.com/MaaXYZ/MaaFramework) 主仓库查看

## Star History

<a href="https://www.star-history.com/#MAA1999/M9A&Date">
 <picture>
   <source media="(prefers-color-scheme: dark)" srcset="https://api.star-history.com/svg?repos=MAA1999/M9A&type=Date&theme=dark" />
   <source media="(prefers-color-scheme: light)" srcset="https://api.star-history.com/svg?repos=MAA1999/M9A&type=Date" />
   <img alt="Star History Chart" src="https://api.star-history.com/svg?repos=MAA1999/M9A&type=Date" />
 </picture>
</a>

## 鸣谢

本项目由 **[MaaFramework](https://github.com/MaaXYZ/MaaFramework)** 强力驱动！  
UI 由 [MFAAvalonia](https://github.com/SweetSmellFox/MFAAvalonia)、~~[MFW-CFA](https://github.com/overflow65537/MFW-PyQt6)~~、~~[MFAWPF](https://github.com/SweetSmellFox/MFAWPF)~~ 大力支持！

感谢以下开发者对本项目作出的贡献:

[![Contributors](https://contrib.rocks/image?repo=MAA1999/M9A&max=1000)](https://github.com/MAA1999/M9A/graphs/contributors)

## Join us

- M9A 交流群 QQ 群：175638678
- M9A 开发群 QQ 群：649344857
- MaaFramework 开发交流 QQ 群: 595990173
